@@ -10,13 +10,16 @@ use autodie;
 use Moose;
 use IO::File;  # This comment creates a bug
 use File::HomeDir;
-use File::Spec::Functions qw(catdir catfile);
 use Version::Compare;
 use Path::Class;
 use ExtUtils::Installed;
 use File::Next;
+use PPI;
+use Term::ANSIColor;
+# For test only during dev
+#use Dependencies::Searcher;
 
-our $VERSION = '0.066_002';
+our $VERSION = '0.066_003';
 
 =head1 NAME
 
@@ -142,7 +145,7 @@ sub get_modules {
     # @path contains files and directories
     my ($self, $pattern, @path) = @_;
 
-    say("Ack pattern : " . $pattern);
+    say("Search pattern : " . $pattern);
 
     my @moduls = $self->search($pattern, @path);
     say("Found $pattern modules : " . @moduls);
@@ -164,18 +167,16 @@ sub get_files {
     my $lib_dir = dir('lib');
     my $make_file = file('Makefile.PL');
     my $script_dir = dir('script');
-    # note t/ is ignored
+    # note1 t/ is ignored
+    # note2 any type of interesting file or dir should be listed here
 
     my @structure;
-    $structure[0] = "";
-    $structure[1] = "";
-    $structure[2] = "";
+
     if (-d $lib_dir) {
-
 	$structure[0] = $lib_dir;
-
     } else {
 	# TODO : TEST IF THE PATH IS OK ???
+        # What can you do if a module don't have a lib/ dir ?
 	die "Don't look like we are working on a Perl module";
     }
 
@@ -483,7 +484,7 @@ sub generate_report {
 
 
 
-# under rewriting
+# under rewriting since we removed Dependencies::Searcher::AckRequester
 sub search {
     my ($self, $pattern, @paths) = @_;
 
@@ -493,14 +494,36 @@ sub search {
 
     # Each path is a file in the chosen hierarchy
     while ( defined ( my $path = $iter->() )) {
-        say($path);
+
+        my $namespace;
         my $file = file($path);
+
+        # We have to test that we don't include namespaces of the
+        # analyzed module
+        my $document = PPI::Document->new($file->stringify);
+        # Testing that the file is actually a module, not for example Makefile.PL
+        my $is_module = $document->find_first('PPI::Statement::Package');
+        if ($is_module) {
+            $namespace = $is_module->namespace;
+        }
+
         my @lines = $file->slurp;
         for my $line (@lines) {
+
             # Remove carriage return
             chomp  $line;
             # Remove tabs
             $line =~ s/^\t+//;
+
+            if ($is_module) {
+                # We jump to the next line if we found the analyzed
+                # package in the array of lines
+                if ($line =~ /use $namespace/ ) {
+                    $self->coucou("Module namespace ($line) has been ommited ")
+                }
+                next if $line =~ $namespace;
+            }
+
             if ($line =~ /^$pattern\s/ ) {
                 say($line);
 
@@ -512,33 +535,11 @@ sub search {
         }
     }
 
+    # TODO retrieve modules from Makefile.PL (it cannot be based on
+    # the use of a "pattern" in this case)
+
     p @modules;
     return @modules;
-
-    # old code
-
-    # my (
-    #     $success,
-    #     $error_message,
-    #     $full_buffer,
-    #     $stdout_buffer,
-    #     $stderr_buffer
-    # ) = run (
-    #     command => $cmd,
-    #     verbose => 0
-    # );
-
-    # my @modules;
-
-    # say("All modules in distribution : " . join "", @$full_buffer);
-
-    # if ($success) {
-    #     push @modules, split(/\n/m, $$full_buffer[0]);
-    # } else {
-    #     say "No module have been found or IPC::Cmd failed with error $error_message";
-    # }
-
-    # return @modules;
 }
 
 # It could be a simplist implementation, but I didn't find something
@@ -547,16 +548,16 @@ sub rm_comments {
 
     my ($self, $dirt) = @_;
 
-    say("Inside rm with $dirt");
-
     # Case #1: "use" declaration line with a comment after
     # The regex add the terminal semicolon at the end of the line to
     # make the difference between comments and code, because "use" is
     # a word that you can find often in a POD section, more much in
     # the beginning of line than you could think
     if ( $dirt =~ /#.+/ ) {
-        say("ENTER IT for $dirt");
+        say("Entered rm_comment for $dirt");
         $dirt =~ s/#(.*)//;
+        # Delete spaces
+        $dirt =~ s/\s*//xi;
     }
 
     # $pattern = "$pattern" . qr/.+;$/; # <= This is an horrible bug,
@@ -572,6 +573,14 @@ sub rm_comments {
     return $clean;
 }
 
+sub coucou {
+    my ($self, $thing, $color) = @_;
+    if (not $color) {
+        $color = 'red';
+    }
+    say(color("$color"), $thing);
+}
+
 
 1;
 
@@ -735,6 +744,12 @@ Supposed to remove any comment from a line.
 
 =cut
 
+=head2 coucou($tring, $color)
+
+Stupid DIY logger
+
+=cut
+
 =head1 CAVEATS
 
 =head2 Low Win32 / Cygwin support
@@ -760,6 +775,8 @@ Command Line Magic (@climagic) tweeted 4:17 PM on lun., nov. 25, 2013
 
 See original Tweet https://twitter.com/climagic/status/404992356513902592
 
+Though, it don't really work, that's why I made this module.
+
 =cut
 
 =head1 BUGS
